@@ -1,9 +1,9 @@
 package Proc::Govern;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-11-29'; # DATE
+our $DATE = '2020-08-18'; # DATE
 our $DIST = 'Proc-Govern'; # DIST
-our $VERSION = '0.209'; # VERSION
+our $VERSION = '0.210'; # VERSION
 
 use 5.010001;
 use strict;
@@ -639,7 +639,7 @@ Proc::Govern - Run child process and govern its various aspects
 
 =head1 VERSION
 
-This document describes version 0.209 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-11-29.
+This document describes version 0.210 of Proc::Govern (from Perl distribution Proc-Govern), released on 2020-08-18.
 
 =head1 SYNOPSIS
 
@@ -795,10 +795,6 @@ Another instance is already running (when C<single_instance> option is true).
 
 =back
 
-=head1 CAVEATS
-
-Not yet tested on Win32.
-
 =head1 FUNCTIONS
 
 
@@ -900,7 +896,7 @@ If not given, will be taken from command.
 
 =item * B<nice> => I<int>
 
-Set nice/priority level.
+Set niceE<sol>priority level.
 
 =item * B<no_screensaver> => I<true>
 
@@ -951,6 +947,7 @@ The killing is implemented using L<IPC::Run>'s C<kill_kill()>.
 
 Upon timeout, exit code is set to 124.
 
+
 =back
 
 Return value: Child's exit code (int)
@@ -995,6 +992,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 CAVEATS
+
+Not yet tested on Win32.
+
 =head1 SEE ALSO
 
 L<Forks::Super> (since 2009) extends the fork(), wait(), and waitpid() functions
@@ -1059,7 +1060,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
